"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildErrors = void 0;
const mustache_1 = require("mustache");
const path_1 = __importDefault(require("path"));
const config_1 = require("../config");
const utils_1 = require("./utils");
function buildErrors(type) {
    return __awaiter(this, void 0, void 0, function* () {
        const tpl = yield utils_1.loadTemplate('error.tpl');
        const destDirPath = path_1.default.join(__dirname, '..', type);
        const items = [];
        const mapping = type === 'client' ? config_1.ClientErrorOptions : config_1.ServerErrorOptions;
        for (let key in mapping) {
            const fileName = mapping[key].statusCode + '-' + (mapping[key].code).toLowerCase().replaceAll('_', '-') + '.ts';
            const destFilePath = path_1.default.join(destDirPath + '/' + fileName);
            let className = key;
            const classErrorSuffix = key.toLocaleLowerCase().endsWith('error');
            if (!classErrorSuffix) {
                className += 'Error';
            }
            const content = mustache_1.render(tpl, Object.assign({ namespaceFile: 'index.ts', decorateMessage: type === 'server', logMessage: type === 'server', class: className }, mapping[key]));
            yield utils_1.saveFile(content, destFilePath);
            items.push({
                fileName,
                className,
                classErrorSuffix
            });
        }
        // default
        let content = items.map(item => {
            const parts = item.fileName.split('.');
            parts.pop();
            return `export * from "./${parts.join('.')}";`;
        }).reduce((prev, current) => prev + "\n" + current);
        let destFilePath = path_1.default.join(destDirPath + '/index.ts');
        yield utils_1.saveFile(content, destFilePath);
        // bundle
        const aliases = [];
        content = items
            .map(item => {
            const parts = item.fileName.split('.');
            parts.pop();
            const alias = item.classErrorSuffix ? item.className : item.className.substr(0, item.className.length - 5);
            aliases.push(alias);
            return `import {${item.className} as ${alias}} from "./${parts.join('.')}";`;
        })
            .reduce((prev, current) => prev + "\n" + current);
        content += `\n` + `export {\n\t${aliases.join(`,\n\t`)}\n};`;
        destFilePath = path_1.default.join(destDirPath + '/aliases.ts');
        yield utils_1.saveFile(content, destFilePath);
    });
}
exports.buildErrors = buildErrors;
//# sourceMappingURL=index.js.map